smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel

# ``smartcard`.`wx`.`SimpleSCardAppFrame`.`TreeAndUserPanelPanel``

class documentation

`class TreeAndUserPanelPanel(wx.Panel):`

View In Hierarchy

The panel that contains the Card/Reader TreeCtrl and the user provided Panel.

Method | `__init__` | Constructor. Creates the panel with two panels:
Method | `ActivateCard` | Activate a card.
Method | `DeactivateCard` | Deactivate a card.
Method | `OnActivateCard` | Called when the user activates a card in the tree.
Method | `OnActivateReader` | Called when the user activates a reader in the tree.
Method | `OnCardRightClick` | Called when user right-clicks a node in the card tree control.
Method | `OnConnect` | Undocumented
Method | `OnDisconnect` | Undocumented
Method | `OnItemCollapsed` | Undocumented
Method | `OnReaderRightClick` | Called when user right-clicks a node in the reader tree control.
Method | `OnSelectCard` | Called when the user selects a card in the tree.
Method | `OnSelectReader` | Called when the user selects a reader in the tree.
Instance Variable | `connectID` | Undocumented
Instance Variable | `dialogpanel` | Undocumented
Instance Variable | `disconnectID` | Undocumented
Instance Variable | `parent` | Undocumented
Instance Variable | `readertreepanel` | Undocumented
Instance Variable | `selectedcard` | Undocumented

def __init__(self, parent, apppanelclass, appstyle):

Constructor. Creates the panel with two panels:

- the left-hand panel is holding the smartcard and/or reader tree
- the right-hand panel is holding the application dialog

Parameters
parent | Undocumented
apppanelclass | the class of the panel to instantiate in the `SimpleSCardAppFrame`
appstyle | a combination of the following styles (bitwise or |) TR_SMARTCARD: display a smartcard tree panel TR_READER: display a reader tree panel TB_SMARTCARD: display a smartcard toolbar TB_SMARTCARD: display a reader toolbar default is TR_DEFAULT = TR_SMARTCARD

def ActivateCard(self, card):

Activate a card.

def DeactivateCard(self, card):

Deactivate a card.

def OnActivateCard(self, event):

Called when the user activates a card in the tree.

def OnActivateReader(self, event):

Called when the user activates a reader in the tree.

def OnCardRightClick(self, event):

Called when user right-clicks a node in the card tree control.

def OnConnect(self, event):

Undocumented

def OnDisconnect(self, event):

Undocumented

def OnItemCollapsed(self, event):

Undocumented

def OnReaderRightClick(self, event):

Called when user right-clicks a node in the reader tree control.

def OnSelectCard(self, event):

Called when the user selects a card in the tree.

def OnSelectReader(self, event):

Called when the user selects a reader in the tree.

connectID =

Undocumented

dialogpanel =

Undocumented

disconnectID =

Undocumented

parent =

Undocumented

readertreepanel =

Undocumented

selectedcard =

Undocumented